@@ -10,7 +10,7 @@ Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of 
+published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -22,6 +22,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "kcalc_version.h"
 #include "kcalc.h"
 
 #include <clocale>
@@ -50,11 +51,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "kcalc_settings.h"
 #include "kcalc_statusbar.h"
 #include "kcalcdisplay.h"
-#include "version.h"
 
 namespace {
 const char description[] = I18N_NOOP("KDE Calculator");
-const char version[]	 = KCALCVERSION;
 const int maxprecision   = 1000;
 }
 
@@ -118,7 +117,7 @@ KCalculator::KCalculator(QWidget *parent) :
 	if (KCalcSettings::captionResult() == true) {
                 connect(calc_display, &KCalcDisplay::changedText, this, &KCalculator::setWindowTitle);
 	}
-     
+
 	calc_display->changeSettings();
 	setPrecision();
 
@@ -1549,7 +1548,7 @@ void KCalculator::slotConstclicked(int button) {
 
 		} else {
 			pbShift->setChecked(false);
-			
+
 			// internally, we deal with C locale style numbers, we need to convert
 			QString val = calc_display->text();
 			val.replace(KNumber::decimalSeparator(), QLatin1String("."));
@@ -2263,25 +2262,29 @@ bool KCalculator::eventFilter(QObject *o, QEvent *e) {
 //------------------------------------------------------------------------------
 extern "C" Q_DECL_EXPORT int kdemain(int argc, char *argv[]) {
 
-       QApplication app(argc, argv);
- 
+    QApplication app(argc, argv);
+
+    /**
+     * enable high dpi support
+     */
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
     Kdelibs4ConfigMigrator migrate(QLatin1String("kcalc"));
     migrate.setConfigFiles(QStringList() << QLatin1String("kcalcrc"));
     migrate.setUiFiles(QStringList() << QLatin1String("kcalcui.rc"));
     migrate.migrate();
 
-	KAboutData aboutData("kcalc",
-		i18n("KCalc"),
-		version,
-		i18n(description),
-		KAboutLicense::GPL,
-		i18n(
-			"Copyright © 2008-2013, Evan Teran\n"
-			"Copyright © 2000-2008, The KDE Team\n"
-			"Copyright © 2003-2005, Klaus Niederkr" "\xc3\xbc" "ger\n"
-			"Copyright © 1996-2000, Bernd Johannes Wuebben"),
-		QString(),
-		"http://utils.kde.org/projects/kcalc");
+    KAboutData aboutData(QStringLiteral("kcalc"),
+                         i18n("KCalc"),
+                         QStringLiteral(KCALC_VERSION_STRING),
+                         i18n(description),
+                         KAboutLicense::GPL,
+                         i18n("Copyright © 2008-2013, Evan Teran\n"
+                              "Copyright © 2000-2008, The KDE Team\n"
+                              "Copyright © 2003-2005, Klaus Niederkr" "\xc3\xbc" "ger\n"
+                              "Copyright © 1996-2000, Bernd Johannes Wuebben"),
+                         QStringLiteral(),
+                         QStringLiteral("http://utils.kde.org/projects/kcalc"));
 
 	// Klaus Niederkrueger
 	aboutData.addAuthor(i18n("Klaus Niederkr" "\xc3\xbc" "ger"), QString(), "kniederk@math.uni-koeln.de");
